summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
Diffstat (limited to 'chrome')
-rw-r--r--chrome/browser/browser_signin.cc2
-rw-r--r--chrome/browser/printing/print_dialog_cloud.cc4
-rw-r--r--chrome/browser/printing/print_dialog_cloud_unittest.cc6
-rw-r--r--chrome/browser/renderer_host/render_process_host.h4
-rw-r--r--chrome/browser/renderer_host/render_view_host.cc6
-rw-r--r--chrome/browser/renderer_host/test/render_process_host_browsertest.cc8
-rw-r--r--chrome/browser/renderer_host/test/site_instance_unittest.cc2
-rw-r--r--chrome/browser/resources/gpu_internals/browser_bridge.js4
-rw-r--r--chrome/browser/resources/host_registration_page.html2
-rw-r--r--chrome/browser/resources/net_internals/index.html2
-rw-r--r--chrome/browser/resources/options/chromeos_internet_options.js2
-rw-r--r--chrome/browser/sync/sync_setup_wizard_unittest.cc4
-rw-r--r--chrome/browser/sync/sync_ui_util.h2
-rw-r--r--chrome/browser/tab_contents/render_view_host_manager_unittest.cc6
-rw-r--r--chrome/browser/ui/browser.cc2
-rw-r--r--chrome/browser/ui/cocoa/clear_browsing_data_controller.h4
-rw-r--r--chrome/browser/ui/cocoa/constrained_html_delegate_mac.mm4
-rw-r--r--chrome/browser/ui/gtk/constrained_html_delegate_gtk.cc2
-rw-r--r--chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc6
-rw-r--r--chrome/common/child_process_info.h4
-rw-r--r--chrome/common/chrome_paths.h2
-rw-r--r--chrome/common/chrome_switches.cc6
-rw-r--r--chrome/common/render_messages_internal.h4
-rw-r--r--chrome/common/url_constants.h2
-rw-r--r--chrome/renderer/render_view.cc2
25 files changed, 46 insertions, 46 deletions
diff --git a/chrome/browser/browser_signin.cc b/chrome/browser/browser_signin.cc
index 96de0e5..a3ab3d8 100644
--- a/chrome/browser/browser_signin.cc
+++ b/chrome/browser/browser_signin.cc
@@ -286,7 +286,7 @@ void BrowserSignin::Cancel() {
void BrowserSignin::OnLoginFinished() {
if (html_dialog_ui_delegate_)
html_dialog_ui_delegate_->ForceDialogClose();
- // The dialog will be deleted by DOMUI due to the dialog close,
+ // The dialog will be deleted by WebUI due to the dialog close,
// don't hold a reference.
html_dialog_ui_delegate_ = NULL;
diff --git a/chrome/browser/printing/print_dialog_cloud.cc b/chrome/browser/printing/print_dialog_cloud.cc
index 9973995..4c50df1 100644
--- a/chrome/browser/printing/print_dialog_cloud.cc
+++ b/chrome/browser/printing/print_dialog_cloud.cc
@@ -62,13 +62,13 @@
// print data and getting any page setup parameters that the dialog
// contents provides. As part of bringing up the dialog,
// HtmlDialogUI::RenderViewCreated is called (an override of
-// DOMUI::RenderViewCreated). That routine, in turn, calls the
+// WebUI::RenderViewCreated). That routine, in turn, calls the
// delegate's GetWebUIMessageHandlers routine, at which point the
// ownership of the CloudPrintFlowHandler is handed over. A pointer
// to the flow handler is kept to facilitate communication back and
// forth between the two classes.
-// The DOMUI continues dialog bring-up, calling
+// The WebUI continues dialog bring-up, calling
// CloudPrintFlowHandler::RegisterMessages. This is where the
// additional object model capabilities are registered for the dialog
// contents to use. It is also at this time that capabilities for the
diff --git a/chrome/browser/printing/print_dialog_cloud_unittest.cc b/chrome/browser/printing/print_dialog_cloud_unittest.cc
index 63dae76..cdb34ee 100644
--- a/chrome/browser/printing/print_dialog_cloud_unittest.cc
+++ b/chrome/browser/printing/print_dialog_cloud_unittest.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -205,7 +205,7 @@ TEST_F(CloudPrintURLTest, CheckDefaultURLs) {
EXPECT_TRUE(test_page_url.has_query());
}
-// Testing for CloudPrintDataSender needs a mock DOMUI.
+// Testing for CloudPrintDataSender needs a mock WebUI.
class CloudPrintDataSenderTest : public testing::Test {
public:
CloudPrintDataSenderTest()
@@ -275,7 +275,7 @@ TEST_F(CloudPrintDataSenderTest, EmptyFile) {
// Testing for CloudPrintFlowHandler needs a mock
// CloudPrintHtmlDialogDelegate, mock CloudPrintDataSender, and a mock
-// DOMUI.
+// WebUI.
// Testing for CloudPrintHtmlDialogDelegate needs a mock
// CloudPrintFlowHandler.
diff --git a/chrome/browser/renderer_host/render_process_host.h b/chrome/browser/renderer_host/render_process_host.h
index 1e8523b..355e6bc 100644
--- a/chrome/browser/renderer_host/render_process_host.h
+++ b/chrome/browser/renderer_host/render_process_host.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -43,7 +43,7 @@ class RenderProcessHost : public IPC::Channel::Sender,
// in which case we call it an "extension" renderer.
enum Type {
TYPE_NORMAL, // Normal renderer, no extra privileges.
- TYPE_DOMUI, // Renderer with DOMUI privileges, like New Tab.
+ TYPE_DOMUI, // Renderer with WebUI privileges, like New Tab.
TYPE_EXTENSION, // Renderer with extension privileges.
};
diff --git a/chrome/browser/renderer_host/render_view_host.cc b/chrome/browser/renderer_host/render_view_host.cc
index 9b7ff5a..b5288f8 100644
--- a/chrome/browser/renderer_host/render_view_host.cc
+++ b/chrome/browser/renderer_host/render_view_host.cc
@@ -217,7 +217,7 @@ void RenderViewHost::Navigate(const ViewMsg_Navigate_Params& params) {
// browser. But we want to keep the throbber in sync with what's happening
// in the UI. For example, we want to start throbbing immediately when the
// user naivgates even if the renderer is delayed. There is also an issue
- // with the throbber starting because the DOMUI (which controls whether the
+ // with the throbber starting because the WebUI (which controls whether the
// favicon is displayed) happens synchronously. If the start loading
// messages was asynchronous, then the default favicon would flash in.
//
@@ -1156,8 +1156,8 @@ void RenderViewHost::OnMsgDOMUISend(
if (value.get())
params.arguments.Swap(static_cast<ListValue*>(value.get()));
params.source_url = source_url;
- // DOMUI doesn't use these values yet.
- // TODO(aa): When DOMUI is ported to ExtensionFunctionDispatcher, send real
+ // WebUI doesn't use these values yet.
+ // TODO(aa): When WebUI is ported to ExtensionFunctionDispatcher, send real
// values here.
params.request_id = -1;
params.has_callback = false;
diff --git a/chrome/browser/renderer_host/test/render_process_host_browsertest.cc b/chrome/browser/renderer_host/test/render_process_host_browsertest.cc
index 04a7c5f..c6e68e7 100644
--- a/chrome/browser/renderer_host/test/render_process_host_browsertest.cc
+++ b/chrome/browser/renderer_host/test/render_process_host_browsertest.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -95,7 +95,7 @@ IN_PROC_BROWSER_TEST_F(RenderProcessHostTest, ProcessPerTab) {
EXPECT_EQ(tab_count, browser()->tab_count());
EXPECT_EQ(host_count, RenderProcessHostCount());
- // Create another new tab. It should share the process with the other DOMUI.
+ // Create another new tab. It should share the process with the other WebUI.
browser()->NewTab();
if (browser()->tab_count() == tab_count)
ui_test_utils::WaitForNewTab(browser());
@@ -103,7 +103,7 @@ IN_PROC_BROWSER_TEST_F(RenderProcessHostTest, ProcessPerTab) {
EXPECT_EQ(tab_count, browser()->tab_count());
EXPECT_EQ(host_count, RenderProcessHostCount());
- // Create another new tab. It should share the process with the other DOMUI.
+ // Create another new tab. It should share the process with the other WebUI.
browser()->NewTab();
if (browser()->tab_count() == tab_count)
ui_test_utils::WaitForNewTab(browser());
@@ -234,7 +234,7 @@ IN_PROC_BROWSER_TEST_F(RenderProcessHostTest, DISABLED_ProcessOverflow) {
// Create another TYPE_DOMUI tab. It should share the process with newtab.
// Note: intentionally create this tab after the TYPE_NORMAL tabs to exercise
- // bug 43448 where extension and DOMUI tabs could get combined into normal
+ // bug 43448 where extension and WebUI tabs could get combined into normal
// renderers.
GURL history(chrome::kChromeUIHistoryURL);
browser()->ShowSingletonTab(history, false);
diff --git a/chrome/browser/renderer_host/test/site_instance_unittest.cc b/chrome/browser/renderer_host/test/site_instance_unittest.cc
index 04ff608..c887607 100644
--- a/chrome/browser/renderer_host/test/site_instance_unittest.cc
+++ b/chrome/browser/renderer_host/test/site_instance_unittest.cc
@@ -439,7 +439,7 @@ TEST_F(SiteInstanceTest, ProcessSharingByType) {
EXPECT_EQ(extension1_instance->GetProcess(),
extension2_instance->GetProcess());
- // Create some DOMUI instances and make sure they share a process.
+ // Create some WebUI instances and make sure they share a process.
scoped_refptr<SiteInstance> dom1_instance(
CreateSiteInstance(&rph_factory, GURL("chrome://newtab")));
policy->GrantWebUIBindings(dom1_instance->GetProcess()->id());
diff --git a/chrome/browser/resources/gpu_internals/browser_bridge.js b/chrome/browser/resources/gpu_internals/browser_bridge.js
index cd1bf6d..1b1e23b 100644
--- a/chrome/browser/resources/gpu_internals/browser_bridge.js
+++ b/chrome/browser/resources/gpu_internals/browser_bridge.js
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -9,7 +9,7 @@ cr.define('gpu', function() {
* @constructor
*/
function BrowserBridge() {
- // If we are not running inside DOMUI, output chrome.send messages
+ // If we are not running inside WebUI, output chrome.send messages
// to the console to help with quick-iteration debugging.
if (chrome.send === undefined && console.log) {
chrome.send = function(messageHandler, args) {
diff --git a/chrome/browser/resources/host_registration_page.html b/chrome/browser/resources/host_registration_page.html
index 058c4c0..fc86439 100644
--- a/chrome/browser/resources/host_registration_page.html
+++ b/chrome/browser/resources/host_registration_page.html
@@ -60,7 +60,7 @@ function setUserInfo(userInfo) {
$('form').contentWindow.postMessage(msg, registrationUrl);
}
-// Called by DOMUI handler when startup manifest is not defined.
+// Called by WebUI handler when startup manifest is not defined.
function skipRegistration() {
location.replace(registerSkipUrl);
}
diff --git a/chrome/browser/resources/net_internals/index.html b/chrome/browser/resources/net_internals/index.html
index f3beb00..d67957c 100644
--- a/chrome/browser/resources/net_internals/index.html
+++ b/chrome/browser/resources/net_internals/index.html
@@ -277,7 +277,7 @@ found in the LICENSE file.
<!-- START OF HELP TEXT -->
<script>
function displayHelpForBugDump() {
- // We can't access the popups loaded from DOMUI pages, so we instead populate
+ // We can't access the popups loaded from WebUI pages, so we instead populate
// its contents using a data:URL. YUCK!
// TODO(eroman): do something less hacky, like exposing a new URL.
var helpContents =
diff --git a/chrome/browser/resources/options/chromeos_internet_options.js b/chrome/browser/resources/options/chromeos_internet_options.js
index ab4a6e3..20c4484 100644
--- a/chrome/browser/resources/options/chromeos_internet_options.js
+++ b/chrome/browser/resources/options/chromeos_internet_options.js
@@ -93,7 +93,7 @@ cr.define('options', function() {
};
// A boolean flag from InternerOptionsHandler to indicate whether to use
- // inline DOMUI for ethernet/wifi login/options.
+ // inline WebUI for ethernet/wifi login/options.
InternetOptions.useSettingsUI = false;
// Network status update will be blocked while typing in WEP password etc.
diff --git a/chrome/browser/sync/sync_setup_wizard_unittest.cc b/chrome/browser/sync/sync_setup_wizard_unittest.cc
index cbf416a..d705706 100644
--- a/chrome/browser/sync/sync_setup_wizard_unittest.cc
+++ b/chrome/browser/sync/sync_setup_wizard_unittest.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -126,7 +126,7 @@ class TestBrowserWindowForWizardTest : public TestBrowserWindow {
virtual ~TestBrowserWindowForWizardTest() {
if (flow_.get()) {
- // In real life, the handlers are destroyed by the DOMUI infrastructure,
+ // In real life, the handlers are destroyed by the WebUI infrastructure,
// which calls GetWebUIMessageHandlers to take ownership. This does not
// exist in our test, so we perform cleanup manually.
std::vector<WebUIMessageHandler*> handlers;
diff --git a/chrome/browser/sync/sync_ui_util.h b/chrome/browser/sync/sync_ui_util.h
index 065f82f..819916d 100644
--- a/chrome/browser/sync/sync_ui_util.h
+++ b/chrome/browser/sync/sync_ui_util.h
@@ -55,7 +55,7 @@ string16 GetSyncMenuLabel(ProfileSyncService* service);
// Open the appropriate sync dialog for the given profile (which can be
// incognito). |browser| is the browser window that should be used if the UI
-// is in-window (i.e., DOMUI). |code| should be one of the START_FROM_* codes.
+// is in-window (i.e., WebUI). |code| should be one of the START_FROM_* codes.
void OpenSyncMyBookmarksDialog(Profile* profile,
Browser* browser,
ProfileSyncService::SyncEventCodes code);
diff --git a/chrome/browser/ui/browser.cc b/chrome/browser/ui/browser.cc
index 4960032..26d36c5 100644
--- a/chrome/browser/ui/browser.cc
+++ b/chrome/browser/ui/browser.cc
@@ -1982,7 +1982,7 @@ void Browser::OpenLanguageOptionsDialog() {
switches::kDisableTabbedOptions)) {
ShowOptionsTab(chrome::kLanguageOptionsSubPage);
} else {
- // Language options dialog has been replaced by DOMUI.
+ // Language options dialog has been replaced by WebUI.
}
}
diff --git a/chrome/browser/ui/cocoa/clear_browsing_data_controller.h b/chrome/browser/ui/cocoa/clear_browsing_data_controller.h
index 2444988..ac52b38 100644
--- a/chrome/browser/ui/cocoa/clear_browsing_data_controller.h
+++ b/chrome/browser/ui/cocoa/clear_browsing_data_controller.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -58,7 +58,7 @@ extern NSString* const kClearBrowsingDataControllerRemoveMask;
// Show the clear browsing data window. Do not use |-initWithProfile:|,
// go through this instead so we don't end up with multiple instances.
-// This function does not block, so it can be used from DOMUI calls.
+// This function does not block, so it can be used from WebUI calls.
+ (void)showClearBrowsingDialogForProfile:(Profile*)profile;
+ (ClearBrowsingDataController*)controllerForProfile:(Profile*)profile;
diff --git a/chrome/browser/ui/cocoa/constrained_html_delegate_mac.mm b/chrome/browser/ui/cocoa/constrained_html_delegate_mac.mm
index 9e0344e..553f3e24 100644
--- a/chrome/browser/ui/cocoa/constrained_html_delegate_mac.mm
+++ b/chrome/browser/ui/cocoa/constrained_html_delegate_mac.mm
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -51,7 +51,7 @@ class ConstrainedHtmlDelegateMac :
HtmlDialogUIDelegate* html_delegate_; // weak.
// The constrained window that owns |this|. Saved here because it needs to be
- // closed in response to the DOMUI OnDialogClose callback.
+ // closed in response to the WebUI OnDialogClose callback.
ConstrainedWindow* constrained_window_;
DISALLOW_COPY_AND_ASSIGN(ConstrainedHtmlDelegateMac);
diff --git a/chrome/browser/ui/gtk/constrained_html_delegate_gtk.cc b/chrome/browser/ui/gtk/constrained_html_delegate_gtk.cc
index ea869ff..ed8d532 100644
--- a/chrome/browser/ui/gtk/constrained_html_delegate_gtk.cc
+++ b/chrome/browser/ui/gtk/constrained_html_delegate_gtk.cc
@@ -56,7 +56,7 @@ class ConstrainedHtmlDelegateGtk : public ConstrainedWindowGtkDelegate,
HtmlDialogUIDelegate* html_delegate_;
// The constrained window that owns |this|. It's saved here because it needs
- // to be closed in response to the DOMUI OnDialogClose callback.
+ // to be closed in response to the WebUI OnDialogClose callback.
ConstrainedWindow* window_;
};
diff --git a/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc b/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc
index 594ee39..345482b 100644
--- a/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc
+++ b/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc
@@ -56,13 +56,13 @@ TabContentsViewViews::~TabContentsViewViews() {
void TabContentsViewViews::AttachConstrainedWindow(
ConstrainedWindowGtk* constrained_window) {
- // TODO(anicolao): reimplement all dialogs as DOMUI
+ // TODO(anicolao): reimplement all dialogs as WebUI
NOTIMPLEMENTED();
}
void TabContentsViewViews::RemoveConstrainedWindow(
ConstrainedWindowGtk* constrained_window) {
- // TODO(anicolao): reimplement all dialogs as DOMUI
+ // TODO(anicolao): reimplement all dialogs as WebUI
NOTIMPLEMENTED();
}
@@ -328,6 +328,6 @@ void TabContentsViewViews::WasSized(const gfx::Size& size) {
}
void TabContentsViewViews::SetFloatingPosition(const gfx::Size& size) {
- // TODO(anicolao): rework this once we have DOMUI views for dialogs
+ // TODO(anicolao): rework this once we have WebUI views for dialogs
SetBounds(x(), y(), size.width(), size.height());
}
diff --git a/chrome/common/child_process_info.h b/chrome/common/child_process_info.h
index b083ea5..8d4e60e 100644
--- a/chrome/common/child_process_info.h
+++ b/chrome/common/child_process_info.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -37,7 +37,7 @@ class ChildProcessInfo {
enum RendererProcessType {
RENDERER_UNKNOWN = 0,
RENDERER_NORMAL,
- RENDERER_CHROME, // DOMUI (chrome:// URL)
+ RENDERER_CHROME, // WebUI (chrome:// URL)
RENDERER_EXTENSION, // chrome-extension://
RENDERER_DEVTOOLS, // Web inspector
RENDERER_INTERSTITIAL, // malware/phishing interstitial
diff --git a/chrome/common/chrome_paths.h b/chrome/common/chrome_paths.h
index 0626fc2..74f7920 100644
--- a/chrome/common/chrome_paths.h
+++ b/chrome/common/chrome_paths.h
@@ -24,7 +24,7 @@ enum {
DIR_RESOURCES, // Directory containing separate file resources
// used by Chrome at runtime.
DIR_SHARED_RESOURCES, // Directory containing js and css files used
- // by DOMUI and component extensions.
+ // by WebUI and component extensions.
DIR_INSPECTOR, // Directory where web inspector is located.
DIR_APP_DICTIONARIES, // Directory where the global dictionaries are.
DIR_USER_DOCUMENTS, // Directory for a user's "My Documents".
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index c417ff9..cb8ef8c 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -373,7 +373,7 @@ const char kDisableSyncPreferences[] = "disable-sync-preferences";
// Disable syncing of themes.
const char kDisableSyncThemes[] = "disable-sync-themes";
-// Disable tabbed options, i.e., DOMUI version of options window.
+// Disable tabbed options, i.e., WebUI version of options window.
const char kDisableTabbedOptions[] = "disable-tabbed-options";
// TabCloseableStateWatcher disallows closing of tabs and browsers under certain
@@ -1317,7 +1317,7 @@ const char kCompressSystemFeedback[] = "compress-sys-feedback";
// switch separates chrome code from the rest of ChromeOS.
const char kForceStubLibcros[] = "force-stub-libcros";
-// Enables DOMUI menu.
+// Enables WebUI menu.
const char kEnableDOMUIMenu[] = "enable-domui-menu";
// Enables Media Player.
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index ef434ed..57e405a 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -496,8 +496,8 @@ IPC_MESSAGE_ROUTED0(ViewMsg_DragSourceSystemDragEnded)
IPC_MESSAGE_ROUTED1(ViewMsg_AllowBindings,
int /* enabled_bindings_flags */)
-// Tell the renderer to add a property to the DOMUI binding object. This
-// only works if we allowed DOMUI bindings.
+// Tell the renderer to add a property to the WebUI binding object. This
+// only works if we allowed WebUI bindings.
IPC_MESSAGE_ROUTED2(ViewMsg_SetDOMUIProperty,
std::string /* property_name */,
std::string /* property_value_json */)
diff --git a/chrome/common/url_constants.h b/chrome/common/url_constants.h
index dac3dcc..6bc0165 100644
--- a/chrome/common/url_constants.h
+++ b/chrome/common/url_constants.h
@@ -15,7 +15,7 @@ extern const char kAboutScheme[];
extern const char kBlobScheme[];
extern const char kChromeDevToolsScheme[];
extern const char kChromeInternalScheme[];
-extern const char kChromeUIScheme[]; // The scheme used for DOMUIs.
+extern const char kChromeUIScheme[]; // The scheme used for WebUIs.
extern const char kCrosScheme[]; // The scheme used for ChromeOS.
extern const char kDataScheme[];
extern const char kExtensionScheme[];
diff --git a/chrome/renderer/render_view.cc b/chrome/renderer/render_view.cc
index 54673fd..7ac9c84 100644
--- a/chrome/renderer/render_view.cc
+++ b/chrome/renderer/render_view.cc
@@ -2926,7 +2926,7 @@ WebNavigationPolicy RenderView::decidePolicyForNavigation(
GURL old_url(frame->url());
// Detect when we're crossing a permission-based boundary (e.g. into or out of
- // an extension or app origin, leaving a DOMUI page, etc). We only care about
+ // an extension or app origin, leaving a WebUI page, etc). We only care about
// top-level navigations within the current tab (as opposed to, for example,
// opening a new window). But we sometimes navigate to about:blank to clear a
// tab, and we want to still allow that.
diff --git a/chrome/browser/tab_contents/render_view_host_manager_unittest.cc b/chrome/browser/tab_contents/render_view_host_manager_unittest.cc
index 840edf3..a4b82d8 100644
--- a/chrome/browser/tab_contents/render_view_host_manager_unittest.cc
+++ b/chrome/browser/tab_contents/render_view_host_manager_unittest.cc
@@ -235,8 +235,8 @@ TEST_F(RenderViewHostManagerTest, Navigate) {
NotificationType::RENDER_VIEW_HOST_CHANGED));
}
-// Tests DOMUI creation.
-TEST_F(RenderViewHostManagerTest, DOMUI) {
+// Tests WebUI creation.
+TEST_F(RenderViewHostManagerTest, WebUI) {
BrowserThread ui_thread(BrowserThread::UI, MessageLoop::current());
SiteInstance* instance = SiteInstance::CreateSiteInstance(profile_.get());
@@ -275,7 +275,7 @@ TEST_F(RenderViewHostManagerTest, DOMUI) {
// Web UI renderers, even if --process-per-tab is enabled. In that mode, we
// still swap processes if ShouldSwapProcessesForNavigation is true.
// Regression test for bug 46290.
-TEST_F(RenderViewHostManagerTest, NonDOMUIChromeURLs) {
+TEST_F(RenderViewHostManagerTest, NonWebUIChromeURLs) {
BrowserThread thread(BrowserThread::UI, &message_loop_);
SiteInstance* instance = SiteInstance::CreateSiteInstance(profile_.get());
TestTabContents tab_contents(profile_.get(), instance);